@@ -7,7 +7,7 @@ sf_account = 'ra45066.eu-west-1'
 from toolkit_w.snowflake.snowflakeq import Snowflakeq
 SQ=Snowflakeq()
 
-pwd = getpass.getpass("passsword:")
+# pwd = getpass.getpass("passsword:")
 
 
 
@@ -171,7 +171,7 @@ class Crp:
     def getTotalSpentLMonth(self,train_df,dateFlag_sep,df_matrix):
         """
         Params:
-
+pwd
 
         -----------------
         Output:
@@ -205,7 +205,7 @@ class Crp:
 
 # ----------------------------------------------------------------------------------
 
-    def getFeaturesMatrix(self,train_df,org_df,timeFlag,items_dataset,customer_name,train_window):
+    def getFeaturesMatrix(self,train_df,org_df,timeFlag,items_dataset,customer_name,train_window,sq_pass):
         """
         Params:
             train_df -> train timeframe dataframe
@@ -239,7 +239,7 @@ class Crp:
         # Turn the separators into strings for the snowflake query
         dateFlag_sep = str(dateFlag_sep)
         date_flag_min = str(date_flag_min)
-        orders_param = SQ.get_data_from_sf('V_DIFFDAYSBETWEENPURCHASESAGG',customer_name,pwd,dateFlag_sep,date_flag_min)
+        orders_param = SQ.get_data_from_sf('V_DIFFDAYSBETWEENPURCHASESAGG',customer_name,sq_pass,dateFlag_sep,date_flag_min)
 
         output = pd.merge(df_matrix,orders_param,on='customerid')
         
@@ -271,7 +271,7 @@ class Crp:
 
 
 
-    def prepareDF(self,original_dataset,dateFlag_sep,date_flag_min,lag,items_dataset,customer_name,train_window):
+    def prepareDF(self,original_dataset,dateFlag_sep,date_flag_min,lag,items_dataset,customer_name,train_window,sq_pass):
         """
         Params:
             original_dataset ->
@@ -295,7 +295,7 @@ class Crp:
         target_value = self.getTargetValues(train_data,target_frame)
         print('target value done')
         # Calculate features
-        df = self.getFeaturesMatrix(train_data,original_dataset,lag,items_dataset,customer_name,train_window)
+        df = self.getFeaturesMatrix(train_data,original_dataset,lag,items_dataset,customer_name,train_window,sq_pass)
         
         # Merge feature sets
         # data = self.getMergedDF(df,'customerid')
@@ -311,7 +311,7 @@ class Crp:
         return output
 # -----------------------------------------------------------------------------------------------
 
-    def buildDF(self,original_dataset,lag,train_window,items_dataset,customer_name):
+    def buildDF(self,original_dataset,lag,train_window,items_dataset,customer_name,sq_pass):
         """
         Params:
             original_dataset - > the original raw data 
@@ -333,14 +333,14 @@ class Crp:
         date_flag_min = dateFlag_sep - pd.DateOffset(months=train_window)
         print(dateFlag_sep,date_flag_min)
         # Construct dataframe according to that timeframe
-        output.append(self.prepareDF(original_dataset,dateFlag_sep,date_flag_min,lag,items_dataset,customer_name,train_window))
+        output.append(self.prepareDF(original_dataset,dateFlag_sep,date_flag_min,lag,items_dataset,customer_name,train_window,sq_pass))
         print(dateFlag_sep,date_flag_min)
         # Repeat the procedure until the bottom limit of the trainFrame reaches the minimum date possible according to the original dataset.
         while date_flag_min >= min_date:
         
             dateFlag_sep = dateFlag_sep - pd.DateOffset(months=lag)
             date_flag_min = dateFlag_sep - pd.DateOffset(months=train_window)
-            output.append(self.prepareDF(original_dataset,dateFlag_sep,date_flag_min,lag,items_dataset,customer_name,train_window))
+            output.append(self.prepareDF(original_dataset,dateFlag_sep,date_flag_min,lag,items_dataset,customer_name,train_window,sq_pass))
             print(dateFlag_sep,date_flag_min)
             
             
